@@ -13,9 +13,9 @@ def handle_errors(response):
     elif response.status_code == 500:
         raise BobsledException.InternalServerError(status = response.status_code, data = data)
     else:
-        raise BobsledException(status = response.status_code, data = data)
+        raise BobsledException.BobsledException(status = response.status_code, data = data)
 
-def flatten(contents, prefix):
+def flatten(contents, prefix, time=0):
     """Helper function to flatten contents of source bucket
 
     :param contents: dictionary representing source bucket
@@ -23,12 +23,17 @@ def flatten(contents, prefix):
     :return: list of complete file paths for all files in source bucket
     """  
     result = []
-
+    total_size = 0
     for obj in contents:
         if obj["content"] is None:
-          result.append(prefix + obj["id"])
+            timestamp = obj["lastModified"] // 1000
+            if timestamp >= time:
+                total_size += obj["size"]
+                result.append(prefix + obj["id"])
         else:
-            result.extend(flatten(obj["content"], prefix))
+            files, size = flatten(obj["content"], prefix, time)
+            result.extend(files)
+            total_size += size
 
-    return result
+    return result, total_size
   
\ No newline at end of file
